@@ -252,10 +252,7 @@ const char *cipher_opts[] = {
    suboption.  On exit *OPTIONP is set to the beginning of the next
    token or at the terminating NUL character.  */
 static int
-_gsasl_getsubopt (optionp, tokens, valuep)
-     char **optionp;
-     char *const *tokens;
-     char **valuep;
+_gsasl_getsubopt (char **optionp, char *const *tokens, char **valuep)
 {
   char *endp, *vstart;
   int cnt;
@@ -327,7 +324,8 @@ _gsasl_getsubopt (optionp, tokens, valuep)
 
 static int
 _gsasl_digest (char *output,	/* must have 2*MD5LEN available bytes */
-	       char secret[MD5LEN], char *nonce, uint32_t nc, char *cnonce, int qop, char *authzid, char *digesturi, char *a2string,	/* "AUTHENTICATE:" or ":" */
+	       char secret[MD5LEN], char *nonce, uint32_t nc, char *cnonce, int qop, char *authzid, char *digesturi,
+	       const char *a2string,	/* "AUTHENTICATE:" or ":" */
 	       int cipher,	/* used by kcc and kcs */
 	       char *kic,	/* output client integrity key, may be NULL */
 	       char *kis,	/* output server integrity key, may be NULL */
@@ -741,7 +739,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 	memcpy (zinput, input, input_len);
 	zinput[input_len] = '\0';
 
-	gsasl_randomize (0, state->cnonce, CNONCE_ENTROPY_BITS / 8);
+	gsasl_nonce (state->cnonce, CNONCE_ENTROPY_BITS / 8);
 	for (i = 0; i < CNONCE_ENTROPY_BITS / 8; i++)
 	  {
 	    state->cnonce[CNONCE_ENTROPY_BITS / 8 + i] =
@@ -911,6 +909,8 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 
 	if (cb_qop)
 	  state->qop = cb_qop (sctx, state->qop);
+	else
+	  state->qop = GSASL_QOP_AUTH;
 
 	if (maxbuf == -1)
 	  maxbuf = MAXBUF_DEFAULT;
@@ -1039,7 +1039,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 	}
 	/* qop */
 	{
-	  char *qopstr;
+	  const char *qopstr;
 
 	  if (state->qop & GSASL_QOP_AUTH_CONF)
 	    qopstr = QOP_AUTH_CONF;
@@ -1233,7 +1233,7 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 	/* cipher */
 	if (state->qop & GSASL_QOP_AUTH_CONF)
 	  {
-	    char *cipherstr;
+	    const char *cipherstr;
 
 	    if (state->cipher & GSASL_CIPHER_AES)
 	      cipherstr = CIPHER_AES;
@@ -1590,7 +1590,7 @@ _gsasl_digest_md5_server_start (Gsasl_session_ctx * sctx, void **mech_data)
   state->qop = GSASL_QOP_AUTH | GSASL_QOP_AUTH_INT | GSASL_QOP_AUTH_CONF;
   state->cipher = GSASL_CIPHER_DES | GSASL_CIPHER_3DES | GSASL_CIPHER_RC4 |
     GSASL_CIPHER_RC4_40 | GSASL_CIPHER_RC4_56 | GSASL_CIPHER_AES;
-  gsasl_randomize (0, state->nonce, NONCE_ENTROPY_BITS / 8);
+  gsasl_nonce (state->nonce, NONCE_ENTROPY_BITS / 8);
   state->readseqnum = 0;
   state->sendseqnum = 0;
 
