@@ -35,6 +35,9 @@
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
+#ifdef HAVE_ERRNO_H
+# include <errno.h>
+#endif
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>		/* select() */
 #endif
@@ -42,31 +45,39 @@
 # include <netdb.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
-# include <sys/socket.h>		/* for AF_INET */
+# include <sys/socket.h>	/* for AF_INET */
 #endif
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>		/* select() */
 #endif
+#ifdef HAVE_PWD_H
+# include <pwd.h>		/* getpwnam */
+#endif
 
 #ifdef HAVE_NETINET_IN_H
 # include <netinet/in.h>
 #endif
 
-#ifdef HAVE_LOCALE_H
-# include <locale.h>
-#endif
-
 #ifdef WITH_STRINGPREP
 # include <stringprep.h>
 #endif
 
 #include <gsasl.h>
 
-/* Get strdup. */
+/* Gnulib. */
 #include "strdup.h"
+#include "progname.h"
+#include "error.h"
+#include "getpassword.h"
 
-#include "gettext.h"
-#define _(String) dgettext (PACKAGE, String)
+/* Get i18n. */
+#include <gettext.h>
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#else
+# define setlocale(Category, Locale)	/* empty */
+#endif
+#define _(String) gettext (String)
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
 
