@@ -23,6 +23,13 @@
 # include "config.h"
 #endif
 
+/* FIXME. We need the library config.h too. */
+#undef PACKAGE
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#include "lib/config.h"
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
